@@ -1,4 +1,4 @@
-"""Main file of yamlbase"""
+"""Main file of yamlbase.py"""
 
 import argparse
 import yaml
@@ -10,9 +10,9 @@ import sys
 
 if __name__ == '__main__':
 
-    sys.path.append('src/yamlbase')
+    sys.path.append('src/yamlbase.py')
 
-    with open('src/yamlbase/descriptions_cfg.yaml') as f:
+    with open('src/yamlbase.py/descriptions_cfg.yaml') as f:
         descriptions = yaml.load(f)
 
     parser = argparse.ArgumentParser(description=descriptions['arg_parse_descr'])
